@@ -18,7 +18,11 @@
 #ifndef GAMETABLEIMPL_H
 #define GAMETABLEIMPL_H
 
+#ifdef GUI_800x480
+#include "ui_gametable_800x480.h"
+#else
 #include "ui_gametable.h"
+#endif
 #include "game_defs.h"
 
 #include <string>
@@ -338,6 +342,7 @@ public slots:
 	void closeMessageBoxes();
 	void hide();
 	void soundEvent_blindsWereSet(int);
+	void enableCallCheckPushButton();
 
 private:
 
@@ -385,6 +390,7 @@ private:
 	QTimer *blinkingStartButtonAnimationTimer;
 	QTimer *voteOnKickTimeoutTimer;
 	boost::timers::portable::microsec_timer voteOnKickRealTimer;
+	QTimer *enableCallCheckPushButtonTimer;
 
 	QWidget *userWidgetsArray[6];
 	QLabel *buttonLabelArray[MAX_NUMBER_OF_PLAYERS];
