@@ -542,16 +542,16 @@ QStringList guiLog::translateCardCode(int cardCode)
 	switch (color) {
 
 	case 0:
-		cardString << "d";
+		cardString << "&diams;";
 		break;
 	case 1:
-		cardString << "h";
+		cardString << "&hearts;";
 		break;
 	case 2:
-		cardString << "s";
+		cardString << "&spades;";
 		break;
 	case 3:
-		cardString << "c";
+		cardString << "&clubs;";
 		break;
 	default:
 		cardString << "ERROR";
@@ -582,7 +582,7 @@ void guiLog::writeLogFileStream(string log_string, QFile *LogFile)
 
 	QTextStream stream( LogFile );
 	stream.readAll();
-	stream << log_string.data();
+	stream << log_string.c_str();
 
 }
 
@@ -597,7 +597,7 @@ void guiLog::writeLog(string log_string, int modus)
 		writeLogFileStream(log_string,myTxtLogFile);
 		break;
 	case 3:
-		tb->append(log_string.data());
+		tb->append(log_string.c_str());
 		break;
 	default:
 		;
@@ -712,13 +712,13 @@ int guiLog::exportLog(QString fileStringPdb,int modus)
 
 	// open sqlite log-db
 	sqlite3 *mySqliteLogDb;
-	sqlite3_open(fileStringPdb.toStdString().data(), &mySqliteLogDb);
+	sqlite3_open(fileStringPdb.toStdString().c_str(), &mySqliteLogDb);
 	if( mySqliteLogDb != 0 ) {
 
 		// read session
 		sql = "SELECT * FROM Session";
-		if(sqlite3_get_table(mySqliteLogDb,sql.data(),&results.result_Session,&nRow_Session,&nCol_Session,&errmsg) != SQLITE_OK) {
-			cout << "Error in statement: " << sql.data() << "[" << errmsg << "]." << endl;
+		if(sqlite3_get_table(mySqliteLogDb,sql.c_str(),&results.result_Session,&nRow_Session,&nCol_Session,&errmsg) != SQLITE_OK) {
+			cout << "Error in statement: " << sql.c_str() << "[" << errmsg << "]." << endl;
 			cleanUp(results, mySqliteLogDb);
 			return 1;
 		}
@@ -779,7 +779,7 @@ int guiLog::exportLog(QString fileStringPdb,int modus)
 		switch(modus) {
 		case 1:
 			log_string = "<h3><b>" + log_string + "</b></h3>\n";
-			if(!neu) log_string = "<img src='logo.png'>\n" + log_string;
+			// if(!neu) log_string = "<img src='logo.png'>\n" + log_string;
 			break;
 		case 2:
 			log_string += "";
@@ -795,8 +795,8 @@ int guiLog::exportLog(QString fileStringPdb,int modus)
 
 		// read game
 		sql = "SELECT * FROM Game";
-		if(sqlite3_get_table(mySqliteLogDb,sql.data(),&results.result_Game,&nRow_Game,&nCol_Game,&errmsg) != SQLITE_OK) {
-			cout << "Error in statement: " << sql.data() << "[" << errmsg << "]." << endl;
+		if(sqlite3_get_table(mySqliteLogDb,sql.c_str(),&results.result_Game,&nRow_Game,&nCol_Game,&errmsg) != SQLITE_OK) {
+			cout << "Error in statement: " << sql.c_str() << "[" << errmsg << "]." << endl;
 			cleanUp(results, mySqliteLogDb);
 			return 1;
 		}
@@ -836,8 +836,8 @@ int guiLog::exportLog(QString fileStringPdb,int modus)
 			sql  = "SELECT Player,Seat FROM Player WHERE UniqueGameID=";
 			sql += boost::lexical_cast<std::string>(uniqueGameID);
 			sql += " ORDER BY Seat;";
-			if(sqlite3_get_table(mySqliteLogDb,sql.data(),&results.result_Player,&nRow_Player,&nCol_Player,&errmsg) != SQLITE_OK) {
-				cout << "Error in statement: " << sql.data() << "[" << errmsg << "]." << endl;
+			if(sqlite3_get_table(mySqliteLogDb,sql.c_str(),&results.result_Player,&nRow_Player,&nCol_Player,&errmsg) != SQLITE_OK) {
+				cout << "Error in statement: " << sql.c_str() << "[" << errmsg << "]." << endl;
 				cleanUp(results, mySqliteLogDb);
 				return 1;
 			}
@@ -848,8 +848,8 @@ int guiLog::exportLog(QString fileStringPdb,int modus)
 			// read all hand id
 			sql = "SELECT HandID FROM Hand WHERE UniqueGameID=";
 			sql+= boost::lexical_cast<std::string>(uniqueGameID);
-			if(sqlite3_get_table(mySqliteLogDb,sql.data(),&results.result_Hand_ID,&nRow_Hand_ID,&nCol_Hand,&errmsg) != SQLITE_OK) {
-				cout << "Error in statement: " << sql.data() << "[" << errmsg << "]." << endl;
+			if(sqlite3_get_table(mySqliteLogDb,sql.c_str(),&results.result_Hand_ID,&nRow_Hand_ID,&nCol_Hand,&errmsg) != SQLITE_OK) {
+				cout << "Error in statement: " << sql.c_str() << "[" << errmsg << "]." << endl;
 				cleanUp(results, mySqliteLogDb);
 				return 1;
 			}
@@ -886,8 +886,8 @@ int guiLog::exportLog(QString fileStringPdb,int modus)
 				sql+= boost::lexical_cast<std::string>(uniqueGameID);
 				sql+= " AND HandID=";
 				sql+= boost::lexical_cast<std::string>(results.result_Hand_ID[hand_ctr]);
-				if(sqlite3_get_table(mySqliteLogDb,sql.data(),&results.result_Hand,&nRow_Hand,&nCol_Hand,&errmsg) != SQLITE_OK) {
-					cout << "Error in statement: " << sql.data() << "[" << errmsg << "]." << endl;
+				if(sqlite3_get_table(mySqliteLogDb,sql.c_str(),&results.result_Hand,&nRow_Hand,&nCol_Hand,&errmsg) != SQLITE_OK) {
+					cout << "Error in statement: " << sql.c_str() << "[" << errmsg << "]." << endl;
 					cleanUp(results, mySqliteLogDb);
 					return 1;
 				}
@@ -1002,8 +1002,8 @@ int guiLog::exportLog(QString fileStringPdb,int modus)
 					sql += boost::lexical_cast<std::string>(GAME_STATE_PREFLOP);
 					sql += " AND (Action='posts small blind' OR Action='posts big blind' OR Action='starts as dealer')";
 
-					if(sqlite3_get_table(mySqliteLogDb,sql.data(),&results.result_Action,&nRow_Action,&nCol_Action,&errmsg) != SQLITE_OK) {
-						cout << "Error in statement: " << sql.data() << "[" << errmsg << "]." << endl;
+					if(sqlite3_get_table(mySqliteLogDb,sql.c_str(),&results.result_Action,&nRow_Action,&nCol_Action,&errmsg) != SQLITE_OK) {
+						cout << "Error in statement: " << sql.c_str() << "[" << errmsg << "]." << endl;
 						cleanUp(results, mySqliteLogDb);
 						return 1;
 					}
@@ -1049,8 +1049,8 @@ int guiLog::exportLog(QString fileStringPdb,int modus)
 					sql += boost::lexical_cast<std::string>(results.result_Hand_ID[hand_ctr]);
 					sql += " AND BeRo=0 AND Action='posts small blind'";
 
-					if(sqlite3_get_table(mySqliteLogDb,sql.data(),&results.result_Action,&nRow_Action,&nCol_Action,&errmsg) != SQLITE_OK) {
-						cout << "Error in statement: " << sql.data() << "[" << errmsg << "]." << endl;
+					if(sqlite3_get_table(mySqliteLogDb,sql.c_str(),&results.result_Action,&nRow_Action,&nCol_Action,&errmsg) != SQLITE_OK) {
+						cout << "Error in statement: " << sql.c_str() << "[" << errmsg << "]." << endl;
 						cleanUp(results, mySqliteLogDb);
 						return 1;
 					}
@@ -1073,8 +1073,8 @@ int guiLog::exportLog(QString fileStringPdb,int modus)
 					sql += boost::lexical_cast<std::string>(results.result_Hand_ID[hand_ctr]);
 					sql += " AND BeRo=0 AND Action='posts big blind'";
 
-					if(sqlite3_get_table(mySqliteLogDb,sql.data(),&results.result_Action,&nRow_Action,&nCol_Action,&errmsg) != SQLITE_OK) {
-						cout << "Error in statement: " << sql.data() << "[" << errmsg << "]." << endl;
+					if(sqlite3_get_table(mySqliteLogDb,sql.c_str(),&results.result_Action,&nRow_Action,&nCol_Action,&errmsg) != SQLITE_OK) {
+						cout << "Error in statement: " << sql.c_str() << "[" << errmsg << "]." << endl;
 						cleanUp(results, mySqliteLogDb);
 						return 1;
 					}
@@ -1097,8 +1097,8 @@ int guiLog::exportLog(QString fileStringPdb,int modus)
 					sql += boost::lexical_cast<std::string>(results.result_Hand_ID[hand_ctr]);
 					sql += " AND BeRo=0 AND Action='starts as dealer'";
 
-					if(sqlite3_get_table(mySqliteLogDb,sql.data(),&results.result_Action,&nRow_Action,&nCol_Action,&errmsg) != SQLITE_OK) {
-						cout << "Error in statement: " << sql.data() << "[" << errmsg << "]." << endl;
+					if(sqlite3_get_table(mySqliteLogDb,sql.c_str(),&results.result_Action,&nRow_Action,&nCol_Action,&errmsg) != SQLITE_OK) {
+						cout << "Error in statement: " << sql.c_str() << "[" << errmsg << "]." << endl;
 						cleanUp(results, mySqliteLogDb);
 						return 1;
 					}
@@ -1184,7 +1184,7 @@ int guiLog::exportLog(QString fileStringPdb,int modus)
 									if(boost::lexical_cast<std::string>(results.result_Hand[j]) == "BoardCard_"+boost::lexical_cast<std::string>(i)) {
 										if(results.result_Hand[j+nCol_Hand]) {
 											if(modus == 1 || modus == 3) round_string += "<b>";
-											string_tmp = convertCardIntToString(boost::lexical_cast<int>(results.result_Hand[j+nCol_Hand]));
+											string_tmp = convertCardIntToString(boost::lexical_cast<int>(results.result_Hand[j+nCol_Hand]),modus);
 											if(string_tmp == "") {
 												cout << "Implausible board card in uniqueGame " << uniqueGameID << " hand " << results.result_Hand_ID[hand_ctr] << "!" << endl;
 												cleanUp(results, mySqliteLogDb);
@@ -1192,7 +1192,7 @@ int guiLog::exportLog(QString fileStringPdb,int modus)
 											}
 											round_string += boost::lexical_cast<std::string>(string_tmp.at(0));
 											if(modus==1 || modus == 3) round_string += "</b>";
-											round_string += boost::lexical_cast<std::string>(string_tmp.at(1));
+											round_string += boost::lexical_cast<std::string>(string_tmp.erase(0,1));
 											if(round_ctr+2-i > 0) round_string += ",";
 
 											data_found = true;
@@ -1218,8 +1218,8 @@ int guiLog::exportLog(QString fileStringPdb,int modus)
 					sql += boost::lexical_cast<std::string>(round_ctr);
 					sql += " AND Action<>'starts as dealer' AND Action<>'posts big blind' AND Action<>'posts small blind'";
 
-					if(sqlite3_get_table(mySqliteLogDb,sql.data(),&results.result_Action,&nRow_Action,&nCol_Action,&errmsg) != SQLITE_OK) {
-						cout << "Error in statement: " << sql.data() << "[" << errmsg << "]." << endl;
+					if(sqlite3_get_table(mySqliteLogDb,sql.c_str(),&results.result_Action,&nRow_Action,&nCol_Action,&errmsg) != SQLITE_OK) {
+						cout << "Error in statement: " << sql.c_str() << "[" << errmsg << "]." << endl;
 						cleanUp(results, mySqliteLogDb);
 						return 1;
 					}
@@ -1341,7 +1341,7 @@ int guiLog::exportLog(QString fileStringPdb,int modus)
 								cmpString += boost::lexical_cast<std::string>(results.result_Action[3*action_ctr]);
 								cmpString += "_Card_1";
 								if(boost::lexical_cast<std::string>(results.result_Hand[i]) == cmpString) {
-									string_tmp = convertCardIntToString(boost::lexical_cast<int>(results.result_Hand[i+nCol_Hand]));
+									string_tmp = convertCardIntToString(boost::lexical_cast<int>(results.result_Hand[i+nCol_Hand]),modus);
 									if(string_tmp == "") {
 										cout << "Hole card information implausible in uniqueGame " << uniqueGameID << " hand " << results.result_Hand_ID[hand_ctr] << "!" << endl;
 										cleanUp(results, mySqliteLogDb);
@@ -1349,7 +1349,7 @@ int guiLog::exportLog(QString fileStringPdb,int modus)
 									}
 									log_string += boost::lexical_cast<std::string>(string_tmp.at(0));
 									if(modus == 1 || modus == 3) log_string += "</b>";
-									log_string += boost::lexical_cast<std::string>(string_tmp.at(1));
+									log_string += boost::lexical_cast<std::string>(string_tmp.erase(0,1));
 									log_string += ",";
 									if(modus == 1 || modus == 3) log_string += "<b>";
 									data_found = true;
@@ -1368,7 +1368,7 @@ int guiLog::exportLog(QString fileStringPdb,int modus)
 								cmpString += boost::lexical_cast<std::string>(results.result_Action[3*action_ctr]);
 								cmpString += "_Card_2";
 								if(boost::lexical_cast<std::string>(results.result_Hand[i]) == cmpString) {
-									string_tmp = convertCardIntToString(boost::lexical_cast<int>(results.result_Hand[i+nCol_Hand]));
+									string_tmp = convertCardIntToString(boost::lexical_cast<int>(results.result_Hand[i+nCol_Hand]),modus);
 									if(string_tmp == "") {
 										cout << "Hole card information implausible in uniqueGame " << uniqueGameID << " hand " << results.result_Hand_ID[hand_ctr] << "!" << endl;
 										cleanUp(results, mySqliteLogDb);
@@ -1376,7 +1376,7 @@ int guiLog::exportLog(QString fileStringPdb,int modus)
 									}
 									log_string += boost::lexical_cast<std::string>(string_tmp.at(0));
 									if(modus == 1 || modus == 3) log_string += "</b>";
-									log_string += boost::lexical_cast<std::string>(string_tmp.at(1));
+									log_string += boost::lexical_cast<std::string>(string_tmp.erase(0,1));
 									log_string += "]";
 									data_found = true;
 								}
@@ -1445,7 +1445,7 @@ int guiLog::convertCardStringToInt(string val, string col)
 
 	int tmp;
 
-	switch(*col.data()) {
+	switch(*col.c_str()) {
 	case 'd':
 		tmp = 0;
 		break;
@@ -1462,7 +1462,7 @@ int guiLog::convertCardStringToInt(string val, string col)
 		return -1;
 	}
 
-	switch(*val.data()) {
+	switch(*val.c_str()) {
 	case '2':
 		tmp += 0;
 		break;
@@ -1510,7 +1510,7 @@ int guiLog::convertCardStringToInt(string val, string col)
 
 }
 
-string guiLog::convertCardIntToString(int code)
+string guiLog::convertCardIntToString(int code, int modus)
 {
 
 	string tmp;
@@ -1559,21 +1559,44 @@ string guiLog::convertCardIntToString(int code)
 		return "";
 	}
 
-	switch(code/13) {
-	case 0:
-		tmp+= "d";
-		break;
-	case 1:
-		tmp+= "h";
-		break;
-	case 2:
-		tmp+= "s";
-		break;
-	case 3:
-		tmp+= "c";
-		break;
-	default:
-		return "";
+	if(modus==2) {
+
+		switch(code/13) {
+		case 0:
+			tmp+= "d";
+			break;
+		case 1:
+			tmp+= "h";
+			break;
+		case 2:
+			tmp+= "s";
+			break;
+		case 3:
+			tmp+= "c";
+			break;
+		default:
+			return "";
+		}
+
+	} else {
+
+		switch(code/13) {
+		case 0:
+			tmp+= "&diams;";
+			break;
+		case 1:
+			tmp+= "&hearts;";
+			break;
+		case 2:
+			tmp+= "&spades;";
+			break;
+		case 3:
+			tmp+= "&clubs;";
+			break;
+		default:
+			return "";
+		}
+
 	}
 
 	return tmp;
