@@ -266,6 +266,7 @@ void settingsDialogImpl::prepareDialog()
 	checkBox_cardsChanceMonitor->setChecked(myConfig->readConfigInt("ShowCardsChanceMonitor"));
 	checkBox_dontTranslatePokerStrings->setChecked(myConfig->readConfigInt("DontTranslateInternationalPokerStringsFromStyle"));
 	checkBox_disableSplashscreen->setChecked(myConfig->readConfigInt("DisableSplashScreenOnStartup"));
+	checkBox_enableAccidentallyCallBlocker->setChecked(myConfig->readConfigInt("AccidentallyCallBlocker"));
 
 	//S t y l e
 	//TABLE
@@ -661,6 +662,7 @@ void settingsDialogImpl::isAccepted()
 	myConfig->writeConfigInt("DontTranslateInternationalPokerStringsFromStyle", checkBox_dontTranslatePokerStrings->isChecked());
 	myConfig->writeConfigInt("DisableSplashScreenOnStartup", checkBox_disableSplashscreen->isChecked());
 	myConfig->writeConfigInt("EnableBetInputFocusSwitch", checkBox_enableBetInputFocusSwitch->isChecked());
+	myConfig->writeConfigInt("AccidentallyCallBlocker", checkBox_enableAccidentallyCallBlocker->isChecked());
 	myConfig->writeConfigInt("FlipsideTux", radioButton_flipsideTux->isChecked());
 	myConfig->writeConfigInt("FlipsideOwn", radioButton_flipsideOwn->isChecked());
 
@@ -898,6 +900,10 @@ void settingsDialogImpl::setLogDir()
 		if(logDir.exists()) {
 			lineEdit_logDir->setText(dir);
 			refreshLogFileList();
+			QMessageBox::information(this, tr("Settings Information"),
+									 tr("You have changed the log file directory.\n"
+										"Please restart PokerTH to use the new directory for the log files!"),
+									 QMessageBox::Ok);
 		} else {
 			QMessageBox::warning(this, tr("Settings Error"),
 								 tr("The log file directory doesn't exist.\n"
@@ -1350,8 +1356,9 @@ void settingsDialogImpl::exportLogToHtml()
 	QTreeWidgetItem* selectedItem = treeWidget_logFiles->currentItem();
 
 	if(selectedItem) {
+		QFileInfo fi(selectedItem->text(0));
 		QString fileName = QFileDialog::getSaveFileName(this, tr("Export PokerTH log file to HTML"),
-						   QDir::homePath()+"/"+selectedItem->text(0),
+						   QDir::homePath()+"/"+fi.baseName()+".html",
 						   tr("PokerTH HTML log (*.html)"));
 
 		if(!fileName.isEmpty()) {
@@ -1365,8 +1372,9 @@ void settingsDialogImpl::exportLogToTxt()
 	QTreeWidgetItem* selectedItem = treeWidget_logFiles->currentItem();
 
 	if(selectedItem) {
+		QFileInfo fi(selectedItem->text(0));
 		QString fileName = QFileDialog::getSaveFileName(this, tr("Export PokerTH log file to plain text"),
-						   QDir::homePath()+"/"+selectedItem->text(0),
+						   QDir::homePath()+"/"+fi.baseName()+".txt",
 						   tr("PokerTH plain text log (*.txt)"));
 
 		if(!fileName.isEmpty()) {
@@ -1380,8 +1388,9 @@ void settingsDialogImpl::saveLogFileAs()
 	QTreeWidgetItem* selectedItem = treeWidget_logFiles->currentItem();
 
 	if(selectedItem) {
+		QFileInfo fi(selectedItem->text(0));
 		QString fileName = QFileDialog::getSaveFileName(this, tr("Save PokerTH log file"),
-						   QDir::homePath()+"/"+selectedItem->text(0),
+						   QDir::homePath()+"/"+fi.baseName()+".pdb",
 						   tr("PokerTH SQL log (*.pdb)"));
 
 		if(!fileName.isEmpty()) {
