@@ -1,21 +1,20 @@
-/***************************************************************************
- *   Copyright (C) 2007 by Lothar May                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+/*****************************************************************************
+ * PokerTH - The open source texas holdem engine                             *
+ * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ *                                                                           *
+ * This program is free software: you can redistribute it and/or modify      *
+ * it under the terms of the GNU Affero General Public License as            *
+ * published by the Free Software Foundation, either version 3 of the        *
+ * License, or (at your option) any later version.                           *
+ *                                                                           *
+ * This program is distributed in the hope that it will be useful,           *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU Affero General Public License for more details.                       *
+ *                                                                           *
+ * You should have received a copy of the GNU Affero General Public License  *
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *****************************************************************************/
 
 #include <boost/asio.hpp>
 #include <net/socket_helper.h>
@@ -23,7 +22,6 @@
 #include <net/clientstate.h>
 #include <net/clientcontext.h>
 #include <net/senderhelper.h>
-#include <net/receiverhelper.h>
 #include <net/downloaderthread.h>
 #include <net/clientexception.h>
 #include <net/socket_msg.h>
@@ -37,47 +35,29 @@
 
 #include <boost/lambda/lambda.hpp>
 #include <sstream>
+#include <fstream>
 #include <memory>
 #include <cassert>
 #include <gsasl.h>
 
-#define TEMP_AVATAR_FILENAME "avatar.tmp"
+#define TEMP_AVATAR_FILENAME	"avatar.tmp"
+#define TEMP_GUID_FILENAME		"guid.tmp"
+#define CLIENT_GUID_SIZE		16
 #define CLIENT_AVATAR_LOOP_MSEC	100
 #define CLIENT_SEND_LOOP_MSEC	50
 
 using namespace std;
 using boost::asio::ip::tcp;
 
-
-class ClientSenderCallback : public SenderCallback, public SessionDataCallback
+ClientThread::ClientThread(GuiInterface &gui, AvatarManager &avatarManager, Log *myLog)
+	: m_ioService(new boost::asio::io_service), m_clientLog(myLog), m_curState(NULL), m_gui(gui),
+	  m_avatarManager(avatarManager), m_isServerSelected(false),
+	  m_curGameId(0), m_curGameNum(1), m_guiPlayerId(0), m_sessionEstablished(false),
+	  m_stateTimer(*m_ioService), m_avatarTimer(*m_ioService)
 {
-public:
-	ClientSenderCallback() {}
-	virtual ~ClientSenderCallback() {}
-
-	virtual void SignalNetError(SessionId /*session*/, int /*errorID*/, int /*osErrorID*/)
-	{
-	}
-
-	virtual void SignalSessionTerminated(unsigned /*session*/)
-	{
-	}
-
-private:
-};
-
-ClientThread::ClientThread(GuiInterface &gui, AvatarManager &avatarManager)
-: m_ioService(new boost::asio::io_service), m_curState(NULL), m_gui(gui),
-  m_avatarManager(avatarManager), m_isServerSelected(false),
-  m_curGameId(0), m_curGameNum(1), m_guiPlayerId(0), m_sessionEstablished(false),
-  m_stateTimer(*m_ioService), m_avatarTimer(*m_ioService)
-{
-	m_clientLog.reset(new Log("", 0));
 	m_context.reset(new ClientContext);
-	m_receiver.reset(new ReceiverHelper);
 	myQtToolsInterface.reset(CreateQtToolsWrapper());
-	m_senderCallback.reset(new ClientSenderCallback());
-	m_senderHelper.reset(new SenderHelper(*m_senderCallback, m_ioService));
+	m_senderHelper.reset(new SenderHelper(m_ioService));
 }
 
 ClientThread::~ClientThread()
@@ -87,12 +67,12 @@ ClientThread::~ClientThread()
 void
 ClientThread::Init(
 	const string &serverAddress, const string &serverListUrl,
+	const string &serverPassword,
 	bool useServerList, unsigned serverPort, bool ipv6, bool sctp,
 	const string &avatarServerAddress, const string &playerName,
 	const string &avatarFile, const string &cacheDir)
 {
-	if (IsRunning())
-	{
+	if (IsRunning()) {
 		assert(false);
 		return;
 	}
@@ -103,12 +83,15 @@ ClientThread::Init(
 	context.SetAddrFamily(ipv6 ? AF_INET6 : AF_INET);
 	context.SetServerAddr(serverAddress);
 	context.SetServerListUrl(serverListUrl);
+	context.SetServerPassword(serverPassword);
 	context.SetUseServerList(useServerList);
 	context.SetServerPort(serverPort);
 	context.SetAvatarServerAddr(avatarServerAddress);
 	context.SetPlayerName(playerName);
 	context.SetAvatarFile(avatarFile);
 	context.SetCacheDir(cacheDir);
+
+	ReadSessionGuidFromFile();
 }
 
 void
@@ -148,7 +131,10 @@ ClientThread::SendStartEvent(bool fillUpWithCpuPlayers)
 	packet->GetMsg()->present = PokerTHMessage_PR_startEventMessage;
 	StartEventMessage_t *netStartEvent = &packet->GetMsg()->choice.startEventMessage;
 	netStartEvent->gameId = GetGameId();
-	netStartEvent->fillWithComputerPlayers = fillUpWithCpuPlayers;
+
+	netStartEvent->startEventType.present = startEventType_PR_startEvent;
+	StartEvent_t *start = &netStartEvent->startEventType.choice.startEvent;
+	start->fillWithComputerPlayers = fillUpWithCpuPlayers;
 	m_ioService->post(boost::bind(&ClientThread::SendSessionPacket, shared_from_this(), packet));
 }
 
@@ -184,7 +170,7 @@ ClientThread::SendGameChatMessage(const std::string &msg)
 	ChatRequestMessage_t *netChat = &packet->GetMsg()->choice.chatRequestMessage;
 	OCTET_STRING_fromBuf(&netChat->chatText,
 						 msg.c_str(),
-						 msg.length());
+						 (int)msg.length());
 
 	netChat->chatRequestType.present = chatRequestType_PR_chatRequestTypeGame;
 	netChat->chatRequestType.choice.chatRequestTypeGame.gameId = GetGameId();
@@ -203,7 +189,7 @@ ClientThread::SendLobbyChatMessage(const std::string &msg)
 	ChatRequestMessage_t *netChat = &packet->GetMsg()->choice.chatRequestMessage;
 	OCTET_STRING_fromBuf(&netChat->chatText,
 						 msg.c_str(),
-						 msg.length());
+						 (int)msg.length());
 
 	netChat->chatRequestType.present = chatRequestType_PR_chatRequestTypeLobby;
 
@@ -221,7 +207,7 @@ ClientThread::SendPrivateChatMessage(unsigned targetPlayerId, const std::string
 	ChatRequestMessage_t *netChat = &packet->GetMsg()->choice.chatRequestMessage;
 	OCTET_STRING_fromBuf(&netChat->chatText,
 						 msg.c_str(),
-						 msg.length());
+						 (int)msg.length());
 
 	netChat->chatRequestType.present = chatRequestType_PR_chatRequestTypePrivate;
 	netChat->chatRequestType.choice.chatRequestTypePrivate.targetPlayerId = targetPlayerId;
@@ -231,71 +217,87 @@ ClientThread::SendPrivateChatMessage(unsigned targetPlayerId, const std::string
 }
 
 void
-ClientThread::SendJoinFirstGame(const std::string &password)
+ClientThread::SendJoinFirstGame(const std::string &password, bool autoLeave)
 {
 	// Warning: This function is called in the context of the GUI thread.
 	// Create a network packet to request joining a game.
 	boost::shared_ptr<NetPacket> packet(new NetPacket(NetPacket::Alloc));
 	packet->GetMsg()->present = PokerTHMessage_PR_joinGameRequestMessage;
 	JoinGameRequestMessage_t *netJoinGame = &packet->GetMsg()->choice.joinGameRequestMessage;
-	if (!password.empty())
-	{
-		netJoinGame->password = OCTET_STRING_new_fromBuf(
-			&asn_DEF_UTF8String,
-			password.c_str(),
-			password.length());
-	}
+	netJoinGame->autoLeave = autoLeave;
 	netJoinGame->joinGameAction.present = joinGameAction_PR_joinExistingGame;
 
 	JoinExistingGame_t *joinExisting = &netJoinGame->joinGameAction.choice.joinExistingGame;
 	joinExisting->gameId = 1;
+	if (!password.empty()) {
+		joinExisting->password = OCTET_STRING_new_fromBuf(
+									 &asn_DEF_UTF8String,
+									 password.c_str(),
+									 (int)password.length());
+	}
 	m_ioService->post(boost::bind(&ClientThread::SendSessionPacket, shared_from_this(), packet));
 }
 
 void
-ClientThread::SendJoinGame(unsigned gameId, const std::string &password)
+ClientThread::SendJoinGame(unsigned gameId, const std::string &password, bool autoLeave)
 {
 	// Warning: This function is called in the context of the GUI thread.
 	// Create a network packet to request joining a game.
 	boost::shared_ptr<NetPacket> packet(new NetPacket(NetPacket::Alloc));
 	packet->GetMsg()->present = PokerTHMessage_PR_joinGameRequestMessage;
 	JoinGameRequestMessage_t *netJoinGame = &packet->GetMsg()->choice.joinGameRequestMessage;
-	if (!password.empty())
-	{
-		netJoinGame->password = OCTET_STRING_new_fromBuf(
-			&asn_DEF_UTF8String,
-			password.c_str(),
-			password.length());
-	}
+	netJoinGame->autoLeave = autoLeave;
 	netJoinGame->joinGameAction.present = joinGameAction_PR_joinExistingGame;
 
 	JoinExistingGame_t *joinExisting = &netJoinGame->joinGameAction.choice.joinExistingGame;
 	joinExisting->gameId = gameId;
+	if (!password.empty()) {
+		joinExisting->password = OCTET_STRING_new_fromBuf(
+									 &asn_DEF_UTF8String,
+									 password.c_str(),
+									 (int)password.length());
+	}
 	m_ioService->post(boost::bind(&ClientThread::SendSessionPacket, shared_from_this(), packet));
 }
 
 void
-ClientThread::SendCreateGame(const GameData &gameData, const std::string &name, const std::string &password)
+ClientThread::SendRejoinGame(unsigned gameId, bool autoLeave)
+{
+	// Warning: This function is called in the context of the GUI thread.
+	// Create a network packet to request rejoining a running game.
+	boost::shared_ptr<NetPacket> packet(new NetPacket(NetPacket::Alloc));
+	packet->GetMsg()->present = PokerTHMessage_PR_joinGameRequestMessage;
+	JoinGameRequestMessage_t *netJoinGame = &packet->GetMsg()->choice.joinGameRequestMessage;
+	netJoinGame->autoLeave = autoLeave;
+	netJoinGame->joinGameAction.present = joinGameAction_PR_rejoinExistingGame;
+
+	RejoinExistingGame_t *rejoinExisting = &netJoinGame->joinGameAction.choice.rejoinExistingGame;
+	rejoinExisting->gameId = gameId;
+	m_ioService->post(boost::bind(&ClientThread::SendSessionPacket, shared_from_this(), packet));
+}
+
+void
+ClientThread::SendCreateGame(const GameData &gameData, const std::string &name, const std::string &password, bool autoLeave)
 {
 	// Warning: This function is called in the context of the GUI thread.
 	// Create a network packet to request creating a new game.
 	boost::shared_ptr<NetPacket> packet(new NetPacket(NetPacket::Alloc));
 	packet->GetMsg()->present = PokerTHMessage_PR_joinGameRequestMessage;
 	JoinGameRequestMessage_t *netJoinGame = &packet->GetMsg()->choice.joinGameRequestMessage;
-	if (!password.empty())
-	{
-		netJoinGame->password = OCTET_STRING_new_fromBuf(
-			&asn_DEF_UTF8String,
-			password.c_str(),
-			password.length());
-	}
+	netJoinGame->autoLeave = autoLeave;
 	netJoinGame->joinGameAction.present = joinGameAction_PR_joinNewGame;
 
 	JoinNewGame_t *joinNew = &netJoinGame->joinGameAction.choice.joinNewGame;
 	NetPacket::SetGameData(gameData, &joinNew->gameInfo);
 	OCTET_STRING_fromBuf(&joinNew->gameInfo.gameName,
 						 name.c_str(),
-						 name.length());
+						 (int)name.length());
+	if (!password.empty()) {
+		joinNew->password = OCTET_STRING_new_fromBuf(
+								&asn_DEF_UTF8String,
+								password.c_str(),
+								(int)password.length());
+	}
 	m_ioService->post(boost::bind(&ClientThread::SendSessionPacket, shared_from_this(), packet));
 }
 
@@ -371,8 +373,7 @@ ClientThread::SendReportAvatar(unsigned reportedPlayerId, const std::string &ava
 	ReportAvatarMessage_t *netReport = &packet->GetMsg()->choice.reportAvatarMessage;
 	netReport->reportedPlayerId = reportedPlayerId;
 	MD5Buf tmpMD5;
-	if (tmpMD5.FromString(avatarHash) && !tmpMD5.IsZero())
-	{
+	if (tmpMD5.FromString(avatarHash) && !tmpMD5.IsZero()) {
 		OCTET_STRING_fromBuf(
 			&netReport->reportedAvatar,
 			(const char *)tmpMD5.GetData(),
@@ -385,39 +386,19 @@ ClientThread::SendReportAvatar(unsigned reportedPlayerId, const std::string &ava
 void
 ClientThread::StartAsyncRead()
 {
-	ReceiveBuffer &buf = GetContext().GetSessionData()->GetReceiveBuffer();
-	GetContext().GetSessionData()->GetAsioSocket()->async_read_some(
-		boost::asio::buffer(buf.recvBuf + buf.recvBufUsed, RECV_BUF_SIZE - buf.recvBufUsed),
-		boost::bind(
-			&ClientThread::HandleRead,
-			shared_from_this(),
-			boost::asio::placeholders::error,
-			boost::asio::placeholders::bytes_transferred));
+	GetContext().GetSessionData()->GetReceiveBuffer().StartAsyncRead(GetContext().GetSessionData());
 }
 
 void
-ClientThread::HandleRead(const boost::system::error_code& ec, size_t bytesRead)
+ClientThread::CloseSession(boost::shared_ptr<SessionData> /*session*/)
 {
-	if (!ec)
-	{
-		ReceiveBuffer &buf = GetContext().GetSessionData()->GetReceiveBuffer();
-		buf.recvBufUsed += bytesRead;
-		GetReceiver().ScanPackets(buf);
+	throw NetException(__FILE__, __LINE__, ERR_SOCK_CONN_RESET, 0);
+}
 
-		while (!buf.receivedPackets.empty())
-		{
-			boost::shared_ptr<NetPacket> packet = buf.receivedPackets.front();
-			buf.receivedPackets.pop_front();
-			if (packet)
-				GetState().HandlePacket(shared_from_this(), packet);
-		}
-		StartAsyncRead();
-	}
-	else
-	{
-		if (ec != boost::asio::error::operation_aborted)
-			throw NetException(__FILE__, __LINE__, ERR_SOCK_CONN_RESET, 0);
-	}
+void
+ClientThread::HandlePacket(boost::shared_ptr<SessionData> /*session*/, boost::shared_ptr<NetPacket> packet)
+{
+	GetState().HandlePacket(shared_from_this(), packet);
 }
 
 void
@@ -443,8 +424,7 @@ ClientThread::GetServerInfo(unsigned serverId) const
 	ServerInfo tmpInfo;
 	boost::mutex::scoped_lock lock(m_serverInfoMapMutex);
 	ServerInfoMap::const_iterator pos = m_serverInfoMap.find(serverId);
-	if (pos != m_serverInfoMap.end())
-	{
+	if (pos != m_serverInfoMap.end()) {
 		tmpInfo = pos->second;
 	}
 	return tmpInfo;
@@ -456,8 +436,7 @@ ClientThread::GetGameInfo(unsigned gameId) const
 	GameInfo tmpInfo;
 	boost::mutex::scoped_lock lock(m_gameInfoMapMutex);
 	GameInfoMap::const_iterator pos = m_gameInfoMap.find(gameId);
-	if (pos != m_gameInfoMap.end())
-	{
+	if (pos != m_gameInfoMap.end()) {
 		tmpInfo = pos->second;
 	}
 	return tmpInfo;
@@ -467,8 +446,7 @@ PlayerInfo
 ClientThread::GetPlayerInfo(unsigned playerId) const
 {
 	PlayerInfo info;
-	if (!GetCachedPlayerInfo(playerId, info))
-	{
+	if (!GetCachedPlayerInfo(playerId, info)) {
 		ostringstream name;
 		name << "#" << playerId;
 
@@ -486,10 +464,8 @@ ClientThread::GetPlayerIdFromName(const string &playerName, unsigned &playerId)
 	PlayerInfoMap::const_reverse_iterator i = m_playerInfoMap.rbegin();
 	PlayerInfoMap::const_reverse_iterator end = m_playerInfoMap.rend();
 
-	while (i != end)
-	{
-		if (i->second.playerName == playerName)
-		{
+	while (i != end) {
+		if (i->second.playerName == playerName) {
 			playerId = i->first;
 			retVal = true;
 			break;
@@ -508,14 +484,11 @@ ClientThread::GetGameIdOfPlayer(unsigned playerId) const
 	boost::mutex::scoped_lock lock(m_gameInfoMapMutex);
 	GameInfoMap::const_iterator i = m_gameInfoMap.begin();
 	GameInfoMap::const_iterator i_end = m_gameInfoMap.end();
-	while (i != i_end)
-	{
+	while (i != i_end) {
 		PlayerIdList::const_iterator j = (*i).second.players.begin();
 		PlayerIdList::const_iterator j_end = (*i).second.players.end();
-		while (j != j_end)
-		{
-			if (playerId == *j)
-			{
+		while (j != j_end) {
+			if (playerId == *j) {
 				gameId = (*i).first;
 				break;
 			}
@@ -540,6 +513,12 @@ ClientThread::GetGui()
 	return m_gui;
 }
 
+boost::shared_ptr<Log>
+ClientThread::GetClientLog()
+{
+	return m_clientLog;
+}
+
 AvatarManager &
 ClientThread::GetAvatarManager()
 {
@@ -551,8 +530,7 @@ ClientThread::Main()
 {
 	// Main loop.
 	boost::asio::io_service::work ioWork(*m_ioService);
-	try
-	{
+	try {
 		InitAuthContext();
 		// Start sub-threads.
 		m_avatarDownloader.reset(new DownloaderThread);
@@ -563,8 +541,7 @@ ClientThread::Main()
 		boost::asio::io_service::work ioWork(*m_ioService);
 		m_ioService->run(); // Will only be aborted asynchronously.
 
-	} catch (const PokerTHException &e)
-	{
+	} catch (const PokerTHException &e) {
 		GetCallback().SignalNetClientError(e.GetErrorId(), e.GetOsErrorCode());
 	}
 	// Close the socket.
@@ -605,8 +582,7 @@ ClientThread::InitAuthContext()
 	if (res != GSASL_OK)
 		throw ClientException(__FILE__, __LINE__, ERR_NET_GSASL_INIT_FAILED, 0);
 
-	if (!gsasl_server_support_p(m_authContext, "SCRAM-SHA-1"))
-	{
+	if (!gsasl_server_support_p(m_authContext, "SCRAM-SHA-1")) {
 		gsasl_done(m_authContext);
 		throw ClientException(__FILE__, __LINE__, ERR_NET_GSASL_NO_SCRAM, 0);
 	}
@@ -622,12 +598,17 @@ ClientThread::ClearAuthContext()
 void
 ClientThread::InitGame()
 {
+	// Store current session guid, in case we need to rejoin the game.
+	WriteSessionGuidToFile();
+
 	// EngineFactory erstellen
 	boost::shared_ptr<EngineFactory> factory(new ClientEngineFactory); // LocalEngine erstellen
 
 	MapPlayerDataList();
-	if (GetPlayerDataList().size() != (unsigned)GetStartData().numberOfPlayers)
-		throw ClientException(__FILE__, __LINE__, ERR_NET_INVALID_PLAYER_COUNT, 0);
+	// TODO
+	//if (GetPlayerDataList().size() != (unsigned)GetStartData().numberOfPlayers)
+	//	throw ClientException(__FILE__, __LINE__, ERR_NET_INVALID_PLAYER_COUNT, 0);
+	m_startData.numberOfPlayers = GetPlayerDataList().size();
 	m_game.reset(new Game(&m_gui, factory, GetPlayerDataList(), GetGameData(), GetStartData(), m_curGameNum++, m_clientLog.get()));
 	// Initialize Minimum GUI speed.
 	int minimumGuiSpeed = 1;
@@ -652,13 +633,11 @@ ClientThread::SendSessionPacket(boost::shared_ptr<NetPacket> packet)
 void
 ClientThread::SendQueuedPackets()
 {
-	if (!m_outPacketList.empty())
-	{
+	if (!m_outPacketList.empty()) {
 		NetPacketList::iterator i = m_outPacketList.begin();
 		NetPacketList::iterator end = m_outPacketList.end();
 
-		while (i != end)
-		{
+		while (i != end) {
 			GetSender().Send(GetContext().GetSessionData(), *i);
 			++i;
 		}
@@ -673,8 +652,7 @@ ClientThread::GetCachedPlayerInfo(unsigned id, PlayerInfo &info) const
 
 	boost::mutex::scoped_lock lock(m_playerInfoMapMutex);
 	PlayerInfoMap::const_iterator pos = m_playerInfoMap.find(id);
-	if (pos != m_playerInfoMap.end())
-	{
+	if (pos != m_playerInfoMap.end()) {
 		info = pos->second;
 		retVal = true;
 	}
@@ -684,8 +662,7 @@ ClientThread::GetCachedPlayerInfo(unsigned id, PlayerInfo &info) const
 void
 ClientThread::RequestPlayerInfo(unsigned id, bool requestAvatar)
 {
-	if (find(m_playerInfoRequestList.begin(), m_playerInfoRequestList.end(), id) == m_playerInfoRequestList.end())
-	{
+	if (find(m_playerInfoRequestList.begin(), m_playerInfoRequestList.end(), id) == m_playerInfoRequestList.end()) {
 		boost::shared_ptr<NetPacket> packet(new NetPacket(NetPacket::Alloc));
 		packet->GetMsg()->present = PokerTHMessage_PR_playerInfoRequestMessage;
 		PlayerInfoRequestMessage_t *netPlayerInfo = &packet->GetMsg()->choice.playerInfoRequestMessage;
@@ -696,8 +673,7 @@ ClientThread::RequestPlayerInfo(unsigned id, bool requestAvatar)
 
 	}
 	// Remember that we have to request an avatar.
-	if (requestAvatar)
-	{
+	if (requestAvatar) {
 		m_avatarShouldRequestList.push_back(id);
 	}
 }
@@ -712,14 +688,11 @@ ClientThread::SetPlayerInfo(unsigned id, const PlayerInfo &info)
 		// This can only be one entry, since every time a duplicate
 		// name is added one is removed.
 		// Only erase non computer player entries.
-		if (info.playerName.substr(0, sizeof(SERVER_COMPUTER_PLAYER_NAME) - 1) != SERVER_COMPUTER_PLAYER_NAME)
-		{
+		if (info.playerName.substr(0, sizeof(SERVER_COMPUTER_PLAYER_NAME) - 1) != SERVER_COMPUTER_PLAYER_NAME) {
 			PlayerInfoMap::iterator i = m_playerInfoMap.begin();
 			PlayerInfoMap::iterator end = m_playerInfoMap.end();
-			while (i != end)
-			{
-				if (i->first != id && i->second.playerName == info.playerName)
-				{
+			while (i != end) {
+				if (i->first != id && i->second.playerName == info.playerName) {
 					m_playerInfoMap.erase(i);
 					break;
 				}
@@ -730,23 +703,25 @@ ClientThread::SetPlayerInfo(unsigned id, const PlayerInfo &info)
 	}
 
 	// Update player data for current game.
-	boost::shared_ptr<PlayerData> playerData = GetPlayerDataByUniqueId(id);
-	if (playerData.get())
-	{
+	boost::shared_ptr<PlayerData> playerData(GetPlayerDataByUniqueId(id));
+	if (playerData) {
 		playerData->SetName(info.playerName);
 		playerData->SetType(info.ptype);
-		if (info.hasAvatar)
-		{
+		if (info.hasAvatar) {
 			string avatarFile;
-			if (GetAvatarManager().GetAvatarFileName(info.avatar, avatarFile))
-			{
+			if (GetAvatarManager().GetAvatarFileName(info.avatar, avatarFile)) {
 				playerData->SetAvatarFile(GetQtToolsInterface().stringToUtf8(avatarFile));
 			}
 		}
 	}
+	if (GetGame()) {
+		boost::shared_ptr<PlayerInterface> clientPlayer(GetGame()->getPlayerByUniqueId(id));
+		if (clientPlayer)
+			clientPlayer->setMyName(info.playerName);
+		// Skip avatar here, the game is already running.
+	}
 
-	if (find(m_avatarShouldRequestList.begin(), m_avatarShouldRequestList.end(), id) != m_avatarShouldRequestList.end())
-	{
+	if (find(m_avatarShouldRequestList.begin(), m_avatarShouldRequestList.end(), id) != m_avatarShouldRequestList.end()) {
 		m_avatarShouldRequestList.remove(id);
 		// Retrieve avatar if needed.
 		RetrieveAvatarIfNeeded(id, info);
@@ -774,32 +749,29 @@ ClientThread::SetNewGameAdmin(unsigned id)
 {
 	// Update player data for current game.
 	boost::shared_ptr<PlayerData> playerData = GetPlayerDataByUniqueId(id);
-	if (playerData.get())
-	{
+	if (playerData.get()) {
 		playerData->SetGameAdmin(true);
 		GetCallback().SignalNetClientNewGameAdmin(id, playerData->GetName());
+		if(m_game) {
+			m_clientLog->logPlayerAction(playerData->GetName(),LOG_ACTION_ADMIN);
+		}
 	}
 }
 
 void
 ClientThread::RetrieveAvatarIfNeeded(unsigned id, const PlayerInfo &info)
 {
-	if (find(m_avatarHasRequestedList.begin(), m_avatarHasRequestedList.end(), id) == m_avatarHasRequestedList.end())
-	{
-		if (info.hasAvatar && !info.avatar.IsZero() && !GetAvatarManager().HasAvatar(info.avatar))
-		{
+	if (find(m_avatarHasRequestedList.begin(), m_avatarHasRequestedList.end(), id) == m_avatarHasRequestedList.end()) {
+		if (info.hasAvatar && !info.avatar.IsZero() && !GetAvatarManager().HasAvatar(info.avatar)) {
 			m_avatarHasRequestedList.push_back(id); // Never remove from this list. Only request once.
 
 			// Download from avatar server if applicable.
 			string avatarServerAddress(GetContext().GetAvatarServerAddr());
-			if (!avatarServerAddress.empty() && m_avatarDownloader)
-			{
+			if (!avatarServerAddress.empty() && m_avatarDownloader) {
 				string serverFileName(info.avatar.ToString() + AvatarManager::GetAvatarFileExtension(info.avatarType));
 				m_avatarDownloader->QueueDownload(
 					id, avatarServerAddress + serverFileName, GetContext().GetCacheDir() + TEMP_AVATAR_FILENAME);
-			}
-			else
-			{
+			} else {
 				boost::shared_ptr<NetPacket> packet(new NetPacket(NetPacket::Alloc));
 				packet->GetMsg()->present = PokerTHMessage_PR_avatarRequestMessage;
 				AvatarRequestMessage_t *netAvatar = &packet->GetMsg()->choice.avatarRequestMessage;
@@ -857,8 +829,7 @@ ClientThread::PassAvatarFileToManager(unsigned playerId, boost::shared_ptr<Avata
 	PlayerInfo tmpPlayerInfo;
 	if (!GetCachedPlayerInfo(playerId, tmpPlayerInfo))
 		LOG_ERROR("Client received invalid player id!");
-	else
-	{
+	else {
 		if (AvatarFile->fileType == AVATAR_FILE_TYPE_UNKNOWN)
 			AvatarFile->fileType = tmpPlayerInfo.avatarType;
 		if (!GetAvatarManager().StoreAvatarInCache(tmpPlayerInfo.avatar, AvatarFile->fileType, &AvatarFile->fileData[0], AvatarFile->reportedSize, false))
@@ -868,8 +839,7 @@ ClientThread::PassAvatarFileToManager(unsigned playerId, boost::shared_ptr<Avata
 		SetPlayerInfo(playerId, tmpPlayerInfo);
 
 		string fileName;
-		if (GetAvatarManager().GetAvatarFileName(tmpPlayerInfo.avatar, fileName))
-		{
+		if (GetAvatarManager().GetAvatarFileName(tmpPlayerInfo.avatar, fileName)) {
 			// Dynamically update avatar in GUI.
 			GetGui().setPlayerAvatar(playerId, GetQtToolsInterface().stringToUtf8(fileName));
 		}
@@ -886,10 +856,8 @@ ClientThread::SetUnknownAvatar(unsigned playerId)
 void
 ClientThread::TimerCheckAvatarDownloads(const boost::system::error_code& ec)
 {
-	if (!ec)
-	{
-		if (m_avatarDownloader && m_avatarDownloader->HasDownloadResult())
-		{
+	if (!ec) {
+		if (m_avatarDownloader && m_avatarDownloader->HasDownloadResult()) {
 			unsigned playerId;
 			boost::shared_ptr<AvatarFile> tmpAvatar(new AvatarFile);
 			m_avatarDownloader->GetDownloadResult(playerId, tmpAvatar->fileData);
@@ -907,8 +875,7 @@ ClientThread::TimerCheckAvatarDownloads(const boost::system::error_code& ec)
 void
 ClientThread::UnsubscribeLobbyMsg()
 {
-	if (GetContext().GetSubscribeLobbyMsg())
-	{
+	if (GetContext().GetSubscribeLobbyMsg()) {
 		// Send unsubscribe request.
 		boost::shared_ptr<NetPacket> packet(new NetPacket(NetPacket::Alloc));
 		packet->GetMsg()->present = PokerTHMessage_PR_subscriptionRequestMessage;
@@ -922,8 +889,7 @@ ClientThread::UnsubscribeLobbyMsg()
 void
 ClientThread::ResubscribeLobbyMsg()
 {
-	if (!GetContext().GetSubscribeLobbyMsg())
-	{
+	if (!GetContext().GetSubscribeLobbyMsg()) {
 		// Clear game info map as it is outdated.
 		ClearGameInfoMap();
 		// Send resubscribe request.
@@ -967,14 +933,14 @@ ClientThread::CreateContextSession()
 		newSock->set_option(boost::asio::socket_base::keep_alive(true));
 
 		GetContext().SetSessionData(boost::shared_ptr<SessionData>(new SessionData(
-			newSock,
-			SESSION_ID_GENERIC,
-			*m_senderCallback)));
+										newSock,
+										SESSION_ID_GENERIC,
+										*this,
+										*m_ioService)));
 		GetContext().SetResolver(boost::shared_ptr<boost::asio::ip::tcp::resolver>(
-			new boost::asio::ip::tcp::resolver(*m_ioService)));
+									 new boost::asio::ip::tcp::resolver(*m_ioService)));
 		validSocket = true;
-	} catch (...)
-	{
+	} catch (...) {
 	}
 	if (!validSocket)
 		throw ClientException(__FILE__, __LINE__, ERR_SOCK_CREATION_FAILED, 0);
@@ -1009,13 +975,6 @@ ClientThread::GetSender()
 	return *m_senderHelper;
 }
 
-ReceiverHelper &
-ClientThread::GetReceiver()
-{
-	assert(m_receiver);
-	return *m_receiver;
-}
-
 unsigned
 ClientThread::GetGameId() const
 {
@@ -1068,6 +1027,12 @@ ClientThread::GetGuiPlayerId() const
 	return m_guiPlayerId;
 }
 
+int
+ClientThread::GetOrigGuiPlayerNum() const
+{
+	return m_origGuiPlayerNum;
+}
+
 void
 ClientThread::SetGuiPlayerId(unsigned guiPlayerId)
 {
@@ -1088,16 +1053,50 @@ ClientThread::GetQtToolsInterface()
 	return *myQtToolsInterface;
 }
 
+boost::shared_ptr<PlayerData>
+ClientThread::CreatePlayerData(unsigned playerId, bool isGameAdmin)
+{
+	boost::shared_ptr<PlayerData> playerData;
+	PlayerInfo info;
+	if (GetCachedPlayerInfo(playerId, info)) {
+		playerData.reset(
+			new PlayerData(playerId, 0, info.ptype,
+						   info.isGuest ? PLAYER_RIGHTS_GUEST : PLAYER_RIGHTS_NORMAL, isGameAdmin));
+		playerData->SetName(info.playerName);
+		if (info.hasAvatar) {
+			string avatarFile;
+			if (GetAvatarManager().GetAvatarFileName(info.avatar, avatarFile))
+				playerData->SetAvatarFile(GetQtToolsInterface().stringToUtf8(avatarFile));
+			else
+				RetrieveAvatarIfNeeded(playerId, info);
+		}
+	} else {
+		ostringstream name;
+		name << "#" << playerId;
+
+		// Request player info.
+		RequestPlayerInfo(playerId, true);
+		// Use temporary data until the PlayerInfo request is completed.
+		playerData.reset(
+			new PlayerData(playerId, 0, PLAYER_TYPE_HUMAN, PLAYER_RIGHTS_NORMAL, isGameAdmin));
+		playerData->SetName(name.str());
+	}
+	return playerData;
+}
+
 void
 ClientThread::AddPlayerData(boost::shared_ptr<PlayerData> playerData)
 {
-	if (playerData.get() && !playerData->GetName().empty())
-	{
+	if (playerData.get() && !playerData->GetName().empty()) {
 		m_playerDataList.push_back(playerData);
 		if (playerData->GetUniqueId() == GetGuiPlayerId())
 			GetCallback().SignalNetClientSelfJoined(playerData->GetUniqueId(), playerData->GetName(), playerData->IsGameAdmin());
-		else
+		else {
 			GetCallback().SignalNetClientPlayerJoined(playerData->GetUniqueId(), playerData->GetName(), playerData->IsGameAdmin());
+//			if(m_game) {
+//				m_clientLog->logPlayerAction(playerData->GetName(),LOG_ACTION_JOIN);
+//			}
+		}
 	}
 }
 
@@ -1108,10 +1107,8 @@ ClientThread::RemovePlayerData(unsigned playerId, int removeReason)
 
 	PlayerDataList::iterator i = m_playerDataList.begin();
 	PlayerDataList::iterator end = m_playerDataList.end();
-	while (i != end)
-	{
-		if ((*i)->GetUniqueId() == playerId)
-		{
+	while (i != end) {
+		if ((*i)->GetUniqueId() == playerId) {
 			tmpData = *i;
 			m_playerDataList.erase(i);
 			break;
@@ -1119,10 +1116,24 @@ ClientThread::RemovePlayerData(unsigned playerId, int removeReason)
 		++i;
 	}
 
-	if (tmpData.get())
-	{
+	if (tmpData.get()) {
 		// Remove player from gui.
+		if (GetGame()) {
+			boost::shared_ptr<PlayerInterface> tmpPlayer(GetGame()->getPlayerByUniqueId(tmpData->GetUniqueId()));
+			if (tmpPlayer) {
+				tmpPlayer->setMyStayOnTableStatus(false);
+			}
+		}
 		GetCallback().SignalNetClientPlayerLeft(tmpData->GetUniqueId(), tmpData->GetName(), removeReason);
+
+		if(m_game) {
+			if(removeReason == NTF_NET_REMOVED_KICKED) {
+				m_clientLog->logPlayerAction(tmpData->GetName(),LOG_ACTION_KICKED);
+			} else {
+				m_clientLog->logPlayerAction(tmpData->GetName(),LOG_ACTION_LEFT);
+			}
+		}
+
 	}
 }
 
@@ -1138,7 +1149,7 @@ ClientThread::MapPlayerDataList()
 	// Retrieve the GUI player.
 	boost::shared_ptr<PlayerData> guiPlayer = GetPlayerDataByUniqueId(GetGuiPlayerId());
 	assert(guiPlayer.get());
-	int guiPlayerNum = guiPlayer->GetNumber();
+	m_origGuiPlayerNum = guiPlayer->GetNumber();
 
 	// Create a copy of the player list so that the GUI player
 	// is player 0. This is mapped because the GUI depends on it.
@@ -1148,14 +1159,10 @@ ClientThread::MapPlayerDataList()
 	PlayerDataList::const_iterator end = m_playerDataList.end();
 	int numPlayers = GetStartData().numberOfPlayers;
 
-	while (i != end)
-	{
+	while (i != end) {
 		boost::shared_ptr<PlayerData> tmpData(new PlayerData(*(*i)));
-		int numberDiff = tmpData->GetNumber() - guiPlayerNum;
-		if (numberDiff >= 0)
-			tmpData->SetNumber(numberDiff);
-		else
-			tmpData->SetNumber(numPlayers + numberDiff);
+		int numberDiff = numPlayers - m_origGuiPlayerNum;
+		tmpData->SetNumber((tmpData->GetNumber() + numberDiff) % numPlayers);
 		mappedList.push_back(tmpData);
 		++i;
 	}
@@ -1180,10 +1187,8 @@ ClientThread::GetPlayerDataByUniqueId(unsigned id)
 	PlayerDataList::const_iterator i = m_playerDataList.begin();
 	PlayerDataList::const_iterator end = m_playerDataList.end();
 
-	while (i != end)
-	{
-		if ((*i)->GetUniqueId() == id)
-		{
+	while (i != end) {
+		if ((*i)->GetUniqueId() == id) {
 			tmpPlayer = *i;
 			break;
 		}
@@ -1197,15 +1202,12 @@ ClientThread::GetPlayerDataByName(const std::string &name)
 {
 	boost::shared_ptr<PlayerData> tmpPlayer;
 
-	if (!name.empty())
-	{
+	if (!name.empty()) {
 		PlayerDataList::const_iterator i = m_playerDataList.begin();
 		PlayerDataList::const_iterator end = m_playerDataList.end();
 
-		while (i != end)
-		{
-			if ((*i)->GetName() == name)
-			{
+		while (i != end) {
+			if ((*i)->GetName() == name) {
 				tmpPlayer = *i;
 				break;
 			}
@@ -1215,29 +1217,6 @@ ClientThread::GetPlayerDataByName(const std::string &name)
 	return tmpPlayer;
 }
 
-void
-ClientThread::RemoveDisconnectedPlayers()
-{
-	// This should only be called between hands.
-	if (m_game)
-	{
-		PlayerListIterator it;
-		for (it = m_game->getSeatsList()->begin(); it != m_game->getSeatsList()->end(); it++)
-		{
-			boost::shared_ptr<PlayerInterface> tmpPlayer = *it;
-			if (tmpPlayer->getMyActiveStatus())
-			{
-				// If a player is not in the player data list, it was disconnected.
-				if (!GetPlayerDataByUniqueId(tmpPlayer->getMyUniqueID()).get())
-				{
-					tmpPlayer->setMyCash(0);
-					tmpPlayer->setMyActiveStatus(false);
-				}
-			}
-		}
-	}
-}
-
 void
 ClientThread::AddServerInfo(unsigned serverId, const ServerInfo &info)
 {
@@ -1263,8 +1242,7 @@ ClientThread::GetSelectedServer(unsigned &serverId) const
 {
 	bool retVal = false;
 	boost::mutex::scoped_lock lock(m_selectServerMutex);
-	if (m_isServerSelected)
-	{
+	if (m_isServerSelected) {
 		retVal = true;
 		serverId = m_selectedServerId;
 	}
@@ -1291,33 +1269,13 @@ ClientThread::GetLoginData(LoginData &loginData) const
 {
 	bool retVal = false;
 	boost::mutex::scoped_lock lock(m_loginDataMutex);
-	if (!m_loginData.userName.empty())
-	{
+	if (!m_loginData.userName.empty()) {
 		loginData = m_loginData;
 		retVal = true;
 	}
 	return retVal;
 }
 
-unsigned
-ClientThread::GetGameIdByName(const std::string &name) const
-{
-	// Find the game.
-	boost::mutex::scoped_lock lock(m_gameInfoMapMutex);
-	GameInfoMap::const_iterator i = m_gameInfoMap.begin();
-	GameInfoMap::const_iterator end = m_gameInfoMap.end();
-	while (i != end)
-	{
-		if (i->second.name == name)
-			break;
-		++i;
-	}
-
-	if (i == end)
-		throw ClientException(__FILE__, __LINE__, ERR_NET_UNKNOWN_GAME, 0);
-	return i->first;
-}
-
 void
 ClientThread::AddGameInfo(unsigned gameId, const GameInfo &info)
 {
@@ -1335,8 +1293,7 @@ ClientThread::UpdateGameInfoMode(unsigned gameId, GameMode mode)
 	{
 		boost::mutex::scoped_lock lock(m_gameInfoMapMutex);
 		GameInfoMap::iterator pos = m_gameInfoMap.find(gameId);
-		if (pos != m_gameInfoMap.end())
-		{
+		if (pos != m_gameInfoMap.end()) {
 			found = true;
 			(*pos).second.mode = mode;
 		}
@@ -1352,8 +1309,7 @@ ClientThread::UpdateGameInfoAdmin(unsigned gameId, unsigned adminPlayerId)
 	{
 		boost::mutex::scoped_lock lock(m_gameInfoMapMutex);
 		GameInfoMap::iterator pos = m_gameInfoMap.find(gameId);
-		if (pos != m_gameInfoMap.end())
-		{
+		if (pos != m_gameInfoMap.end()) {
 			found = true;
 			(*pos).second.adminPlayerId = adminPlayerId;
 		}
@@ -1369,8 +1325,7 @@ ClientThread::RemoveGameInfo(unsigned gameId)
 	{
 		boost::mutex::scoped_lock lock(m_gameInfoMapMutex);
 		GameInfoMap::iterator pos = m_gameInfoMap.find(gameId);
-		if (pos != m_gameInfoMap.end())
-		{
+		if (pos != m_gameInfoMap.end()) {
 			found = true;
 			m_gameInfoMap.erase(pos);
 		}
@@ -1386,8 +1341,7 @@ ClientThread::ModifyGameInfoAddPlayer(unsigned gameId, unsigned playerId)
 	{
 		boost::mutex::scoped_lock lock(m_gameInfoMapMutex);
 		GameInfoMap::iterator pos = m_gameInfoMap.find(gameId);
-		if (pos != m_gameInfoMap.end())
-		{
+		if (pos != m_gameInfoMap.end()) {
 			pos->second.players.push_back(playerId);
 			playerAdded = true;
 		}
@@ -1403,8 +1357,7 @@ ClientThread::ModifyGameInfoRemovePlayer(unsigned gameId, unsigned playerId)
 	{
 		boost::mutex::scoped_lock lock(m_gameInfoMapMutex);
 		GameInfoMap::iterator pos = m_gameInfoMap.find(gameId);
-		if (pos != m_gameInfoMap.end())
-		{
+		if (pos != m_gameInfoMap.end()) {
 			pos->second.players.remove(playerId);
 			playerRemoved = true;
 		}
@@ -1429,8 +1382,7 @@ ClientThread::StartPetition(unsigned petitionId, unsigned proposingPlayerId, uns
 	}
 	GetGui().startVoteOnKick(kickPlayerId, proposingPlayerId, timeoutSec, numVotesToKick);
 	if (GetGuiPlayerId() != kickPlayerId
-		&& GetGuiPlayerId() != proposingPlayerId)
-	{
+			&& GetGuiPlayerId() != proposingPlayerId) {
 		GetGui().changeVoteOnKickButtonsState(true);
 	}
 }
@@ -1443,8 +1395,7 @@ ClientThread::UpdatePetition(unsigned petitionId, int /*numVotesAgainstKicking*/
 		boost::mutex::scoped_lock lock(m_curPetitionIdMutex);
 		isCurPetition = m_curPetitionId == petitionId;
 	}
-	if (isCurPetition)
-	{
+	if (isCurPetition) {
 		GetGui().refreshVotesMonitor(numVotesInFavourOfKicking, numVotesToKick);
 	}
 }
@@ -1493,8 +1444,7 @@ ClientThread::IsSessionEstablished() const
 void
 ClientThread::SetSessionEstablished(bool flag)
 {
-	if (m_sessionEstablished != flag)
-	{
+	if (m_sessionEstablished != flag) {
 		m_sessionEstablished = flag;
 		if (flag)
 			SendQueuedPackets();
@@ -1507,3 +1457,25 @@ ClientThread::IsSynchronized() const
 	return m_playerInfoRequestList.empty();
 }
 
+void
+ClientThread::ReadSessionGuidFromFile()
+{
+	string guidFileName(GetContext().GetCacheDir() + TEMP_GUID_FILENAME);
+	ifstream guidStream(guidFileName.c_str(), ios::in | ios::binary);
+	if (guidStream.good()) {
+		std::vector<char> tmpGuid(CLIENT_GUID_SIZE);
+		guidStream.read(&tmpGuid[0], CLIENT_GUID_SIZE);
+		GetContext().SetSessionGuid(string(tmpGuid.begin(), tmpGuid.end()));
+	}
+}
+
+void
+ClientThread::WriteSessionGuidToFile() const
+{
+	string guidFileName(GetContext().GetCacheDir() + TEMP_GUID_FILENAME);
+	ofstream guidStream(guidFileName.c_str(), ios::out | ios::trunc | ios::binary);
+	if (guidStream.good()) {
+		guidStream.write(GetContext().GetSessionGuid().c_str(), GetContext().GetSessionGuid().size());
+	}
+}
+
