@@ -891,7 +891,7 @@ ServerLobbyThread::HandlePacket(boost::shared_ptr<SessionData> session, boost::s
 			else if (packet->GetMsg()->present == PokerTHMessage_PR_avatarRequestMessage)
 				HandleNetPacketRetrieveAvatar(session, packet->GetMsg()->choice.avatarRequestMessage);
 			else if (packet->GetMsg()->present == PokerTHMessage_PR_resetTimeoutMessage)
-				{}
+			{}
 			else if (packet->GetMsg()->present == PokerTHMessage_PR_subscriptionRequestMessage) {
 				SubscriptionRequestMessage_t *subscriptionRequest = &packet->GetMsg()->choice.subscriptionRequestMessage;
 				if (subscriptionRequest->subscriptionAction == subscriptionAction_resubscribeGameList)
@@ -2143,7 +2143,7 @@ ServerLobbyThread::GetRejoinGameIdForPlayer(const std::string &playerName, const
 		while (i != end) {
 			boost::shared_ptr<ServerGame> tmpGame = i->second;
 			boost::shared_ptr<PlayerInterface> tmpPlayer = tmpGame->GetPlayerInterfaceFromGame(playerName);
-			if (tmpPlayer && tmpPlayer->getMyGuid() == guid) {
+			if (tmpPlayer && tmpPlayer->getMyGuid() == guid && tmpPlayer->getMyCash() > 0) {
 				retGameId = tmpGame->GetId();
 				outPlayerUniqueId = tmpPlayer->getMyUniqueID();
 				break;
